package com.pwt;

import com.pwt.common.utils.spring.SpringUtils;
import com.pwt.netty.ChargerServer;
import com.pwt.netty.Vehicle2Server;
import com.pwt.netty.client.CodeScannerClient;
import com.pwt.netty.client.PlcClient;
import com.pwt.netty.client.RFIDClient;
import com.pwt.netty.message2.OperationData;
import com.pwt.netty.server.NettyServer;
import com.pwt.system.domain.PwtConfig;
import com.pwt.system.service.IPwtConfigService;
import com.pwt.web.domain.ExchangeStatistics;
import com.pwt.web.domain.PwtHolderBatteryStateCache;
import com.pwt.web.service.IPwtChangeBatteryRecordService;
import com.pwt.web.service.IPwtHolderBatteryStateCacheService;
import com.pwt.web.service.IPwtVehicleService;
import io.netty.channel.ChannelFuture;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.CommandLineRunner;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.autoconfigure.jdbc.DataSourceAutoConfiguration;
import org.springframework.scheduling.annotation.EnableScheduling;

import java.time.Duration;
import java.time.LocalDateTime;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/**
 * 启动程序
 */
@EnableScheduling
@SpringBootApplication(exclude = {DataSourceAutoConfiguration.class})
public class PwtApplication implements CommandLineRunner {

    @Autowired
    private CodeScannerClient codeScannerClient;

    @Autowired
    private RFIDClient rfidClient;

    @Autowired
    private Vehicle2Server vehicleServer;

    @Autowired
    private ChargerServer chargerServer;

    @Autowired
    private PlcClient plcClient;

    @Autowired
    private IPwtChangeBatteryRecordService changeBatteryRecordService;

    @Autowired
    private IPwtVehicleService vehicleService;

    @Autowired
    private IPwtConfigService configService;

    @Autowired
    private IPwtHolderBatteryStateCacheService holderBatteryStateCacheService;

    public static void main(String[] args) {
        // System.setProperty("spring.devtools.restart.enabled", "false");
        SpringApplication.run(PwtApplication.class, args);
        System.out.println("站控系统启动成功...");
    }

    @Override
    public void run(String... args) throws Exception {

        Map<Integer, PwtHolderBatteryStateCache> batteryStateCacheMap = holderBatteryStateCacheService.getBatteryStateCacheMap();

        if (batteryStateCacheMap != null) {
            Globals.holderBatteryStateCacheMap = new ConcurrentHashMap<>(batteryStateCacheMap);
        }

        ExchangeStatistics exchangeStatistics = changeBatteryRecordService.getExchangeStatistics();
        PwtConfig pwtConfig = configService.selectPwtConfigById(1L);
        if (pwtConfig != null && pwtConfig.getChargeSoc() != null) {
            StationService.GET_SOC = pwtConfig.getChargeSoc().intValue();
        }

        Globals.OP_REGISTER_CAR_COUNT.set(vehicleService.getCount());
        Globals.OP_EXCHANGE_COUNT.set(exchangeStatistics.getCount());
        Globals.OP_EXCHANGE_POWER.set(exchangeStatistics.getExchangePower());

        OperationData operationData = new OperationData();
        Duration d = Duration.between(Globals.startDateTime, LocalDateTime.now());
        operationData.setDays(d.toDays());
        operationData.setTotalExchangePower(Globals.OP_EXCHANGE_POWER.get());
        operationData.setTotalExchangeCount(Globals.OP_EXCHANGE_COUNT.get());
        operationData.setTotalRegisterCount(Globals.OP_REGISTER_CAR_COUNT.get());
        Globals.uiData.setOperationData(operationData);

        // todo 链接断线监控
        Globals.plcClient = plcClient;
        plcClient.start();
        codeScannerClient.start();
        rfidClient.start();
        vehicleServer.start();
        chargerServer.start();
        NettyServer nettyServer = SpringUtils.getBean(NettyServer.class);
        ChannelFuture future = nettyServer.start();
    }
}
